@@ -1,6 +1,10 @@
 """ Contains all the data models used in inputs/outputs """
 
+from .active import Active
 from .add_data_column_type import AddDataColumnType
+from .ape import Ape
+from .ape_data import ApeData
+from .ape_data_typeform import ApeDataTypeform
 from .api_column import ApiColumn
 from .api_external_function import ApiExternalFunction
 from .api_table import ApiTable
@@ -9,11 +13,21 @@ from .api_workspace import ApiWorkspace
 from .create_external_function_return_type import CreateExternalFunctionReturnType
 from .create_external_function_runtime import CreateExternalFunctionRuntime
 from .get_table_upload_csv_url_mode import GetTableUploadCsvUrlMode
+from .inactive import Inactive
+from .plugin import Plugin
+from .plugin_external_data import PluginExternalData
+from .plugin_tokens import PluginTokens
 from .presigned_url import PresignedUrl
+from .set_plugin_external_data_json_body import SetPluginExternalDataJsonBody
+from .status import Status
 from .table_row import TableRow
 
 __all__ = (
+    "Active",
     "AddDataColumnType",
+    "Ape",
+    "ApeData",
+    "ApeDataTypeform",
     "ApiColumn",
     "ApiExternalFunction",
     "ApiTable",
@@ -22,6 +36,12 @@ __all__ = (
     "CreateExternalFunctionReturnType",
     "CreateExternalFunctionRuntime",
     "GetTableUploadCsvUrlMode",
+    "Inactive",
+    "Plugin",
+    "PluginExternalData",
+    "PluginTokens",
     "PresignedUrl",
+    "SetPluginExternalDataJsonBody",
+    "Status",
     "TableRow",
 )
